'''
simple.py
simple script for using Sparkfun6DoFIMU with raspberry pi
ryan.j.mortenson@gmail.com
November 12th, 2016
https://github.com/sparkfun/SparkFun_6DOF_IMU_Pi_Library

Resources:
cffi==1.9.1
pycparser==2.17
smbus-cffi==0.5.1

Development environment specifics:
python 2.7
vim 7.4
Raspberry Pi 3
Ubuntu 16.04

This code is released under the [MIT License](http:#opensource.org/licenses/MIT).

Please review the LICENSE.md file included with this example. If you have any questions
or concerns with licensing, please contact techsupport@sparkfun.com.

Distributed as-is; no warranty is given.
'''

import argparse
import logging
import src.itg3200 as Itg3200
import src.adxl345 as Adxl345

if __name__ == "__main__":

    # Setup some arguments for command line execution
    parser = argparse.ArgumentParser()
    parser.add_argument("--i2cbus", "-i", type=int,
                        default=1, help="I2C bus to use default is 1")
    parser.add_argument("--reps", "-r", type=int,
                        default=1, help="Repititions default is 1")
    parser.add_argument("--verbosity", "-v", type=str, choices=["DEBUG", "INFO"],
                        default="INFO", help="Repititions default is 1")
    args = parser.parse_args()

    # Set logging format
    FORMAT = '[%(asctime)s %(filename)15s line: %(lineno)5s] %(message)s'
    logging.basicConfig(format=FORMAT, level=getattr(logging, args.verbosity))
    log = logging.getLogger("main")

    # Instantiate device classes
    itg3200 = Itg3200.Itg3200(args.i2cbus)
    adxl345 = Adxl345.Adxl345(args.i2cbus)

    # Turn on measurement for adxl345
    adxl345.measurement_on()

    for x in range(0, args.reps):
        # Read each Gyro measurement seperately
        log.info("All Gyro values read seperately")
        log.info("Gyro X Axis {}".format(itg3200.get_x_axis()))
        log.info("Gyro Y Axis {}".format(itg3200.get_y_axis()))
        log.info("Gyro Z Axis {}".format(itg3200.get_z_axis()))
        log.info("Gyro Temperature {}".format(itg3200.get_temp()))

        # Read all Gyro measurements at once
        itg3200.get_all()
        log.info("All Gyro values read together")
        log.info("Gyro X Axis {}".format(itg3200.x_axis))
        log.info("Gyro Y Axis {}".format(itg3200.y_axis))
        log.info("Gyro Z Axis {}".format(itg3200.z_axis))
        log.info("Gyro Temperature {}".format(itg3200.temp))

        # Read each Accel measurement seperately
        log.info("All Accel values read seperately")
        log.info("Accel X Accel {}".format(adxl345.get_x_accel()))
        log.info("Accel Y Accel {}".format(adxl345.get_y_accel()))
        log.info("Accel Z Accel {}".format(adxl345.get_z_accel()))

        # Read all Accel measurements at once
        adxl345.get_all()
        log.info("All Accel values read together")
        log.info("Accel X Accel {}".format(adxl345.x_accel))
        log.info("Accel Y Accel {}".format(adxl345.y_accel))
        log.info("Accel Z Accel {}".format(adxl345.z_accel))
